<!--
Copyright (C) 2020 UCT Prague.

oarepo-validate is free software; you can redistribute it and/or modify it
under the terms of the MIT License; see LICENSE file for more details.
-->

# Changes


## Version 1.2.3 (released 2020-08-30)

- Handling pid field in search hit serialization


## Version 1.2.2 (released 2020-08-25)

- Handling pid field in record serialization


## Version 1.2.1 (released 2020-08-25)

- Keeping schema in ``Record.__init__`` (useful mostly for tests)


## Version 1.2.0 (released 2020-08-25)

- Added marshmallow-less loaders and serializers


## Version 1.1.0 (released 2020-08-18)

- Added before and after validation signals.


## Version 1.0.0 (released 2020-08-16)

- Initial public release.
